### Name: mseq-package
### Title: Modeling non-uniformity in short-read rates in RNA-Seq data
### Aliases: mseq-package mseq
### Keywords: package models regression tree

### ** Examples

 # read and expand the data
 data(g1_part) # for real data, please use read.csv, like g1 <- read.csv("g1.csv")
 data <- expData(g1_part, 2, 3) # here the surrounding sequences is only of length 5. In real datasets, it should be larger.
 pdf("ori_counts.pdf")
 plotCounts(data$count[data$index == 1])
 dev.off()

 # get the CV R squared for Poisson linear model
 R_sq <- iterGlmCV(data)

 # train and predict by Poisson linear model
 train.data <- data[data$index < 6, ]
 test.data <- data[data$index >= 6, ]
 train.glm <- iterGlm(train.data)
 pdf("coef.pdf")
 plotCoef(train.glm, 2, 3)
 dev.off()
 pred.pref <- exp(glmPred(train.glm, test.data))

 # get predicted counts
 pred.count <- getPredCount(test.data, pred.pref)
 pdf("glm_fitted_counts.pdf")
 plotCounts(pred.count[data$index == 1])
 dev.off()

 # get the R squared
 glm.dev <- getDev(pred.count, test.data$count)
 null.count <- getNullCount(test.data)
 null.dev <- getDev(null.count, test.data$count)
 R_sq <- 1 - glm.dev / null.dev

 # To shorten the running time, this example uses small values of interaction.depth and n.trees. For real datasets, it is strongly suggested to use their default values.
 # get the CV R squared for MART
 R_sq <- martCV(data, interaction.depth = 2, n.trees = 100)

 # train and predict by MART
 train.data <- data[data$index < 6, ]
 test.data <- data[data$index >= 6, ]
 train.mart <- martTrain(train.data, interaction.depth = 2, n.trees = 100)
 pred.pref <- exp(martPred(train.mart, test.data, n.trees = 100))

 # get predicted counts
 pred.count <- getPredCount(test.data, pred.pref)
 pdf("mart_fitted_counts.pdf")
 plotCounts(pred.count[data$index == 1])
 dev.off()

 # get the R squared
 mart.dev <- getDev(pred.count, test.data$count)
 null.count <- getNullCount(test.data)
 null.dev <- getDev(null.count, test.data$count)
 R_sq <- 1 - mart.dev / null.dev
 
 
 #### Poissong linear model using dinucleotide composition
 # read and expand the data
 data(g1_part) # for real data, please use read.csv, like g1 <- read.csv("g1.csv")
 data <- expData2nt(g1_part, 2, 1) # here the surrounding sequences is only of length 3. In real datasets, it should be larger.

 # get the CV R squared for Poisson linear model
 R_sq <- iterGlmCV2nt(data)

 # train and predict by Poisson linear model
 train.data <- data[data$index < 6, ]
 test.data <- data[data$index >= 6, ]
 train.glm <- iterGlm2nt(train.data)
 pred.pref <- exp(glmPred2nt(train.glm, test.data))



